==> gnumeric-1.1.14.tar.bz2: gnumeric-1.1.14/src/cell.h <==
#ifndef GNUMERIC_CELL_H
#define GNUMERIC_CELL_H

#include "gnumeric.h"
#include "dependent.h"

typedef enum {
	/* MUST BE > 0xFFF,FFFF to avoid conflict with Dependent */
	/* Cell is linked into the sheet */
	CELL_IN_SHEET_LIST  = 0x10000000,
	/* Is the top left corner of a merged region */
	CELL_IS_MERGED	    = 0x20000000,
} CellFlags;

/* Definition of a Gnumeric Cell */
#define DEP_TO_CELL(dep)	((Cell *)(dep))
#define CELL_TO_DEP(cell)	((Dependent *)(cell))
struct _Cell {
	Dependent base;
	/* Mandatory state information */
	CellPos	     pos;
	ColRowInfo  *col_info;
	ColRowInfo  *row_info;

	Value         *value;	/* computed or entered (Must be non NULL) */
	RenderedValue *rendered_value;
};

/**
 * Manage cells
 */
Cell     *cell_new          (void);
Cell	 *cell_copy	    (Cell const *cell);
void	  cell_destroy      (Cell *cell);
void	  cell_relocate     (Cell *cell, GnmExprRewriteInfo const *rwinfo);

/**
 * Cell state checking
 */
#define	    cell_needs_recalc(cell)	((cell)->base.flags & DEPENDENT_NEEDS_RECALC)
#define	    cell_expr_is_linked(cell)	((cell)->base.flags & DEPENDENT_IS_LINKED)
#define	    cell_has_expr(cell)		((cell)->base.expression != NULL)
#define	    cell_is_linked(cell)	((cell)->base.flags & CELL_IN_SHEET_LIST)
#define	    cell_is_merged(cell)	((cell)->base.flags & CELL_IS_MERGED)
CellComment     *cell_has_comment_pos   (const Sheet *sheet, const CellPos *pos);
CellComment     *cell_has_comment	(Cell const *cell);
gboolean	 cell_is_blank		(Cell const *cell);
Value *		 cell_is_error		(Cell const *cell);
gboolean	 cell_is_number		(Cell const *cell);
gboolean	 cell_is_zero		(Cell const *cell);
gboolean	 cell_is_partial_array	(Cell const *cell);
GnmExprArray const *cell_is_array	(Cell const *cell);

/**
 * Utilities to assign the contents of a cell
 */
void cell_set_text		(Cell *c, char const *text);
void cell_assign_value		(Cell *c, Value *v);
void cell_set_value		(Cell *c, Value *v);
void cell_set_expr_and_value	(Cell *c, GnmExpr const *expr, Value *v,
				 gboolean link_expr);
void cell_set_expr		(Cell *c, GnmExpr const *expr);
void cell_set_expr_unsafe 	(Cell *cell, GnmExpr const *expr);
void cell_set_array_formula	(Sheet *sheet,
				 int cola, int rowa, int colb, int rowb,
				 GnmExpr const *expr);
void cell_convert_expr_to_value	(Cell *cell);

/**
 * Manipulate Cell attributes
 */
MStyle *cell_get_mstyle		(Cell const *cell);
StyleFormat *cell_get_format	(Cell const *cell);
void	cell_set_format		(Cell *cell, char const *format);

void	cell_render_value	(Cell *cell, gboolean dynamic_width);
int	cell_rendered_height	(Cell const * cell);
int	cell_rendered_width	(Cell const * cell);	/* excludes offset */
int	cell_rendered_offset	(Cell const * cell);
char *	cell_get_rendered_text	(Cell const * cell);
StyleColor  *cell_get_render_color	(Cell const * cell);
char *	cell_get_entered_text	(Cell const * cell);

guint cellpos_hash (CellPos const *key);
gint  cellpos_cmp  (CellPos const *a, CellPos const *b);

void cell_init (void);
void cell_shutdown (void);

#endif /* GNUMERIC_CELL_H */

==> gnumeric-1.1.16.tar.bz2: gnumeric-1.1.16/src/cell.h <==
#ifndef GNUMERIC_CELL_H
#define GNUMERIC_CELL_H

#include "gnumeric.h"
#include "dependent.h"
#include <pango/pango.h>

typedef enum {
	/* MUST BE > 0xFFF,FFFF to avoid conflict with Dependent */
	/* Cell is linked into the sheet */
	CELL_IN_SHEET_LIST  = 0x10000000,
	/* Is the top left corner of a merged region */
	CELL_IS_MERGED	    = 0x20000000,
} CellFlags;

/* Definition of a Gnumeric Cell */
#define DEP_TO_CELL(dep)	((Cell *)(dep))
#define CELL_TO_DEP(cell)	((Dependent *)(cell))
struct _Cell {
	Dependent base;
	/* Mandatory state information */
	CellPos	     pos;
	ColRowInfo  *col_info;
	ColRowInfo  *row_info;

	Value         *value;	/* computed or entered (Must be non NULL) */
	RenderedValue *rendered_value;
};

/**
 * Manage cells
 */
Cell     *cell_new          (void);
Cell	 *cell_copy	    (Cell const *cell);
void	  cell_destroy      (Cell *cell);
void	  cell_relocate     (Cell *cell, GnmExprRewriteInfo const *rwinfo);

/**
 * Cell state checking
 */
#define	    cell_needs_recalc(cell)	((cell)->base.flags & DEPENDENT_NEEDS_RECALC)
#define	    cell_expr_is_linked(cell)	((cell)->base.flags & DEPENDENT_IS_LINKED)
#define	    cell_has_expr(cell)		((cell)->base.expression != NULL)
#define	    cell_is_linked(cell)	((cell)->base.flags & CELL_IN_SHEET_LIST)
#define	    cell_is_merged(cell)	((cell)->base.flags & CELL_IS_MERGED)
CellComment     *cell_has_comment_pos   (const Sheet *sheet, const CellPos *pos);
CellComment     *cell_has_comment	(Cell const *cell);
gboolean	 cell_is_blank		(Cell const *cell);
Value *		 cell_is_error		(Cell const *cell);
gboolean	 cell_is_number		(Cell const *cell);
gboolean	 cell_is_zero		(Cell const *cell);
gboolean	 cell_is_partial_array	(Cell const *cell);
GnmExprArray const *cell_is_array	(Cell const *cell);

/**
 * Utilities to assign the contents of a cell
 */
void cell_set_text		(Cell *c, char const *text);
void cell_assign_value		(Cell *c, Value *v);
void cell_set_value		(Cell *c, Value *v);
void cell_set_expr_and_value	(Cell *c, GnmExpr const *expr, Value *v,
				 gboolean link_expr);
void cell_set_expr		(Cell *c, GnmExpr const *expr);
void cell_set_expr_unsafe 	(Cell *cell, GnmExpr const *expr);
void cell_set_array_formula	(Sheet *sheet,
				 int cola, int rowa, int colb, int rowb,
				 GnmExpr const *expr);
void cell_convert_expr_to_value	(Cell *cell);

/**
 * Manipulate Cell attributes
 */
MStyle *cell_get_mstyle		(Cell const *cell);
StyleFormat *cell_get_format	(Cell const *cell);
void	cell_set_format		(Cell *cell, char const *format);

void	cell_render_value	(Cell *cell, gboolean dynamic_width);
int	cell_rendered_height	(Cell const * cell);
int	cell_rendered_width	(Cell const * cell);	/* excludes offset */
int	cell_rendered_offset	(Cell const * cell);
char *	cell_get_rendered_text	(Cell const * cell);
const PangoColor* cell_get_render_color	(Cell const * cell);
char *	cell_get_entered_text	(Cell const * cell);

guint cellpos_hash (CellPos const *key);
gint  cellpos_cmp  (CellPos const *a, CellPos const *b);

void cell_init (void);
void cell_shutdown (void);

#endif /* GNUMERIC_CELL_H */
